@@ -5,14 +5,12 @@ package feed
 
 import (
 	"context"
-	"sort"
+	"slices"
 	"strconv"
 	"time"
 
 	"github.com/autobrr/autobrr/internal/domain"
 	"github.com/autobrr/autobrr/internal/proxy"
-	"github.com/autobrr/autobrr/internal/release"
-	"github.com/autobrr/autobrr/internal/scheduler"
 	"github.com/autobrr/autobrr/pkg/errors"
 	"github.com/autobrr/autobrr/pkg/newznab"
 
@@ -20,15 +18,14 @@ import (
 )
 
 type NewznabJob struct {
-	Feed         *domain.Feed
-	Name         string
-	Log          zerolog.Logger
-	URL          string
-	Client       newznab.Client
-	Repo         domain.FeedRepo
-	CacheRepo    domain.FeedCacheRepo
-	ReleaseSvc   release.Service
-	SchedulerSvc scheduler.Service
+	Feed       *domain.Feed
+	Name       string
+	Log        zerolog.Logger
+	URL        string
+	Client     newznab.Client
+	Repo       jobFeedRepo
+	CacheRepo  jobFeedCacheRepo
+	ReleaseSvc jobReleaseSvc
 
 	attempts int
 	errors   []error
@@ -36,7 +33,7 @@ type NewznabJob struct {
 	JobID int
 }
 
-func NewNewznabJob(feed *domain.Feed, name string, log zerolog.Logger, url string, client newznab.Client, repo domain.FeedRepo, cacheRepo domain.FeedCacheRepo, releaseSvc release.Service) FeedJob {
+func NewNewznabJob(feed *domain.Feed, name string, log zerolog.Logger, url string, client newznab.Client, repo jobFeedRepo, cacheRepo jobFeedCacheRepo, releaseSvc jobReleaseSvc) RefreshFeedJob {
 	return &NewznabJob{
 		Feed:       feed,
 		Name:       name,
@@ -85,18 +82,34 @@ func (j *NewznabJob) process(ctx context.Context) error {
 		return nil
 	}
 
+	releases, err := j.processItems(items)
+	if err != nil {
+		j.Log.Error().Err(err).Msgf("error processing items")
+		return errors.Wrap(err, "error processing items")
+	}
+
+	// process all new releases
+	go j.ReleaseSvc.ProcessMultipleFromIndexer(releases, j.Feed.Indexer)
+
+	return nil
+}
+
+func (j *NewznabJob) processItems(items []newznab.FeedItem) ([]*domain.Release, error) {
 	releases := make([]*domain.Release, 0)
 	now := time.Now()
 	for _, item := range items {
+		j.Log.Trace().Str("item", item.Title).Msg("processing item..")
+
 		if j.Feed.MaxAge > 0 {
 			if item.PubDate.After(time.Date(1970, time.April, 1, 0, 0, 0, 0, time.UTC)) {
 				if !isNewerThanMaxAge(j.Feed.MaxAge, item.PubDate.Time, now) {
+					j.Log.Debug().Msgf("item is older than feed max age, skipping: %s", item.Title)
 					continue
 				}
 			}
 		}
 
-		rls := domain.NewRelease(domain.IndexerMinimal{ID: j.Feed.Indexer.ID, Name: j.Feed.Indexer.Name, Identifier: j.Feed.Indexer.Identifier, IdentifierExternal: j.Feed.Indexer.IdentifierExternal})
+		rls := domain.NewRelease(j.Feed.Indexer)
 		rls.Implementation = domain.ReleaseImplementationNewznab
 		rls.Protocol = domain.ReleaseProtocolNzb
 
@@ -123,10 +136,7 @@ func (j *NewznabJob) process(ctx context.Context) error {
 		releases = append(releases, rls)
 	}
 
-	// process all new releases
-	go j.ReleaseSvc.ProcessMultipleFromIndexer(releases, j.Feed.Indexer)
-
-	return nil
+	return releases, nil
 }
 
 func (j *NewznabJob) getFeed(ctx context.Context) ([]newznab.FeedItem, error) {
@@ -160,9 +170,9 @@ func (j *NewznabJob) getFeed(ctx context.Context) ([]newznab.FeedItem, error) {
 		return items, nil
 	}
 
-	sort.SliceStable(feed.Channel.Items, func(i, j int) bool {
-		return feed.Channel.Items[i].PubDate.After(feed.Channel.Items[j].PubDate.Time)
-	})
+	//sort.SliceStable(feed.Channel.Items, func(i, j int) bool {
+	//	return feed.Channel.Items[i].PubDate.After(feed.Channel.Items[j].PubDate.Time)
+	//})
 
 	// Collect all valid GUIDs first
 	guidItemMap := make(map[string]*newznab.FeedItem)
@@ -178,6 +188,9 @@ func (j *NewznabJob) getFeed(ctx context.Context) ([]newznab.FeedItem, error) {
 		guids = append(guids, item.GUID)
 	}
 
+	// reverse order so oldest items are processed first
+	slices.Reverse(guids)
+
 	existingGuids, err := j.CacheRepo.ExistingItems(ctx, j.Feed.ID, guids)
 	if err != nil {
 		j.Log.Error().Err(err).Msg("could not get existing items from cache")
@@ -188,7 +201,8 @@ func (j *NewznabJob) getFeed(ctx context.Context) ([]newznab.FeedItem, error) {
 	ttl := time.Now().AddDate(0, 1, 0)
 	toCache := make([]domain.FeedCacheItem, 0)
 
-	for guid, item := range guidItemMap {
+	for _, guid := range guids {
+		item := guidItemMap[guid]
 		if existingGuids[guid] {
 			j.Log.Trace().Msgf("cache item exists, skipping release: %s", item.Title)
 			continue
