@@ -7,59 +7,89 @@ import (
 )
 
 var (
+	ErrBadCredentials = errors.New("bad credentials")
+	ErrIPBanned       = errors.New("User's IP is banned for too many failed login attempts")
+
+	ErrUnexpectedStatus = errors.New("unexpected status code")
+
+	ErrNoTorrentURLProvided           = errors.New("no torrent URL provided")
+	ErrEmptySavePath                  = errors.New("save path is empty")
+	ErrNoWriteAccessToPath            = errors.New("user does not have write access to directory")
+	ErrCannotCreateSavePath           = errors.New("unable to create save path directory")
+	ErrEmptyCategoryName              = errors.New("category name is empty")
+	ErrInvalidCategoryName            = errors.New("category name is invalid")
+	ErrCategoryEditingFailed          = errors.New("category editing failed")
+	ErrCategoryDoesNotExist           = errors.New("category name does not exist")
+	ErrInvalidPriority                = errors.New("priority is invalid or at least one id is not an integer")
+	ErrTorrentNotFound                = errors.New("torrent not found")
+	ErrTorrentMetdataNotDownloadedYet = errors.New("torrent metadata hasn't downloaded yet or at least one file id was not found")
+	ErrMissingNewPathParameter        = errors.New("missing newPath parameter")
+	ErrInvalidPathParameter           = errors.New("invalid newPath or oldPath, or newPath already in use")
+	ErrInvalidTorrentHash             = errors.New("torrent hash is invalid")
+	ErrEmptyTorrentName               = errors.New("torrent name is empty")
+	ErrAllURLsNotFound                = errors.New("all urls were not found")
+	ErrInvalidURL                     = errors.New("new url is not a valid URL")
+	ErrTorrentQueueingNotEnabled      = errors.New("torrent queueing is not enabled, could not set hashes to max priority")
+	ErrInvalidShareLimit              = errors.New("a share limit or at least one id is invalid")
+	ErrInvalidCookies                 = errors.New("request was not a valid json array of cookie objects")
+	ErrCannotGetTorrentPieceStates    = errors.New("could not get torrent piece states")
+	ErrInvalidPeers                   = errors.New("none of the supplied peers are valid")
+
 	ErrReannounceTookTooLong = errors.New("reannounce took too long, deleted torrent")
+	ErrUnsupportedVersion    = errors.New("qBittorrent version too old, please upgrade to use this feature")
 )
 
 type Torrent struct {
-	AddedOn            int64        `json:"added_on"`
-	AmountLeft         int64        `json:"amount_left"`
-	AutoManaged        bool         `json:"auto_tmm"`
-	Availability       float64      `json:"availability"`
-	Category           string       `json:"category"`
-	Completed          int64        `json:"completed"`
-	CompletionOn       int64        `json:"completion_on"`
-	ContentPath        string       `json:"content_path"`
-	DlLimit            int64        `json:"dl_limit"`
-	DlSpeed            int64        `json:"dlspeed"`
-	DownloadPath       string       `json:"download_path"`
-	Downloaded         int64        `json:"downloaded"`
-	DownloadedSession  int64        `json:"downloaded_session"`
-	ETA                int64        `json:"eta"`
-	FirstLastPiecePrio bool         `json:"f_l_piece_prio"`
-	ForceStart         bool         `json:"force_start"`
-	Hash               string       `json:"hash"`
-	InfohashV1         string       `json:"infohash_v1"`
-	InfohashV2         string       `json:"infohash_v2"`
-	LastActivity       int64        `json:"last_activity"`
-	MagnetURI          string       `json:"magnet_uri"`
-	MaxRatio           float64      `json:"max_ratio"`
-	MaxSeedingTime     int64        `json:"max_seeding_time"`
-	Name               string       `json:"name"`
-	NumComplete        int64        `json:"num_complete"`
-	NumIncomplete      int64        `json:"num_incomplete"`
-	NumLeechs          int64        `json:"num_leechs"`
-	NumSeeds           int64        `json:"num_seeds"`
-	Priority           int64        `json:"priority"`
-	Progress           float64      `json:"progress"`
-	Ratio              float64      `json:"ratio"`
-	RatioLimit         float64      `json:"ratio_limit"`
-	SavePath           string       `json:"save_path"`
-	SeedingTime        int64        `json:"seeding_time"`
-	SeedingTimeLimit   int64        `json:"seeding_time_limit"`
-	SeenComplete       int64        `json:"seen_complete"`
-	SequentialDownload bool         `json:"seq_dl"`
-	Size               int64        `json:"size"`
-	State              TorrentState `json:"state"`
-	SuperSeeding       bool         `json:"super_seeding"`
-	Tags               string       `json:"tags"`
-	TimeActive         int64        `json:"time_active"`
-	TotalSize          int64        `json:"total_size"`
-	Tracker            string       `json:"tracker"`
-	TrackersCount      int64        `json:"trackers_count"`
-	UpLimit            int64        `json:"up_limit"`
-	Uploaded           int64        `json:"uploaded"`
-	UploadedSession    int64        `json:"uploaded_session"`
-	UpSpeed            int64        `json:"upspeed"`
+	AddedOn            int64            `json:"added_on"`
+	AmountLeft         int64            `json:"amount_left"`
+	AutoManaged        bool             `json:"auto_tmm"`
+	Availability       float64          `json:"availability"`
+	Category           string           `json:"category"`
+	Completed          int64            `json:"completed"`
+	CompletionOn       int64            `json:"completion_on"`
+	ContentPath        string           `json:"content_path"`
+	DlLimit            int64            `json:"dl_limit"`
+	DlSpeed            int64            `json:"dlspeed"`
+	DownloadPath       string           `json:"download_path"`
+	Downloaded         int64            `json:"downloaded"`
+	DownloadedSession  int64            `json:"downloaded_session"`
+	ETA                int64            `json:"eta"`
+	FirstLastPiecePrio bool             `json:"f_l_piece_prio"`
+	ForceStart         bool             `json:"force_start"`
+	Hash               string           `json:"hash"`
+	InfohashV1         string           `json:"infohash_v1"`
+	InfohashV2         string           `json:"infohash_v2"`
+	LastActivity       int64            `json:"last_activity"`
+	MagnetURI          string           `json:"magnet_uri"`
+	MaxRatio           float64          `json:"max_ratio"`
+	MaxSeedingTime     int64            `json:"max_seeding_time"`
+	Name               string           `json:"name"`
+	NumComplete        int64            `json:"num_complete"`
+	NumIncomplete      int64            `json:"num_incomplete"`
+	NumLeechs          int64            `json:"num_leechs"`
+	NumSeeds           int64            `json:"num_seeds"`
+	Priority           int64            `json:"priority"`
+	Progress           float64          `json:"progress"`
+	Ratio              float64          `json:"ratio"`
+	RatioLimit         float64          `json:"ratio_limit"`
+	SavePath           string           `json:"save_path"`
+	SeedingTime        int64            `json:"seeding_time"`
+	SeedingTimeLimit   int64            `json:"seeding_time_limit"`
+	SeenComplete       int64            `json:"seen_complete"`
+	SequentialDownload bool             `json:"seq_dl"`
+	Size               int64            `json:"size"`
+	State              TorrentState     `json:"state"`
+	SuperSeeding       bool             `json:"super_seeding"`
+	Tags               string           `json:"tags"`
+	TimeActive         int64            `json:"time_active"`
+	TotalSize          int64            `json:"total_size"`
+	Tracker            string           `json:"tracker"`
+	TrackersCount      int64            `json:"trackers_count"`
+	UpLimit            int64            `json:"up_limit"`
+	Uploaded           int64            `json:"uploaded"`
+	UploadedSession    int64            `json:"uploaded_session"`
+	UpSpeed            int64            `json:"upspeed"`
+	Trackers           []TorrentTracker `json:"trackers"`
 }
 
 type TorrentTrackersResponse struct {
@@ -67,7 +97,7 @@ type TorrentTrackersResponse struct {
 }
 
 type TorrentTracker struct {
-	//Tier          int   `json:"tier"` // can be both empty "" and int
+	// Tier          int   `json:"tier"` // can be both empty "" and int
 	Url           string        `json:"url"`
 	Status        TrackerStatus `json:"status"`
 	NumPeers      int           `json:"num_peers"`
@@ -357,14 +387,15 @@ func (o *TorrentAddOptions) Prepare() map[string]string {
 }
 
 type TorrentFilterOptions struct {
-	Filter   TorrentFilter
-	Category string
-	Tag      string
-	Sort     string
-	Reverse  bool
-	Limit    int
-	Offset   int
-	Hashes   []string
+	Filter          TorrentFilter
+	Category        string
+	Tag             string
+	Sort            string
+	Reverse         bool
+	Limit           int
+	Offset          int
+	Hashes          []string
+	IncludeTrackers bool // qbit 5.1+
 }
 
 type TorrentProperties struct {
@@ -492,7 +523,7 @@ type AppPreferences struct {
 	MaxConcurrentHTTPAnnounces       int         `json:"max_concurrent_http_announces"`
 	MaxConnec                        int         `json:"max_connec"`
 	MaxConnecPerTorrent              int         `json:"max_connec_per_torrent"`
-	MaxRatio                         int         `json:"max_ratio"`
+	MaxRatio                         float64     `json:"max_ratio"`
 	MaxRatioAct                      int         `json:"max_ratio_act"`
 	MaxRatioEnabled                  bool        `json:"max_ratio_enabled"`
 	MaxSeedingTime                   int         `json:"max_seeding_time"`
@@ -609,7 +640,7 @@ type ServerState struct {
 	DlInfoData           int64  `json:"dl_info_data"`
 	DlInfoSpeed          int64  `json:"dl_info_speed"`
 	DlRateLimit          int64  `json:"dl_rate_limit"`
-	FreeSpaceOnDisk      uint64 `json:"free_space_on_disk"`
+	FreeSpaceOnDisk      int64  `json:"free_space_on_disk"`
 	GlobalRatio          string `json:"global_ratio"`
 	QueuedIoJobs         int64  `json:"queued_io_jobs"`
 	Queueing             bool   `json:"queueing"`
@@ -626,3 +657,54 @@ type ServerState struct {
 	UseAltSpeedLimits    bool   `json:"use_alt_speed_limits"`
 	WriteCacheOverload   string `json:"write_cache_overload"`
 }
+
+// Log
+type Log struct {
+	ID        int64  `json:"id"`
+	Message   string `json:"message"`
+	Timestamp int64  `json:"timestamp"`
+	Type      int64  `json:"type"`
+}
+
+// PeerLog
+type PeerLog struct {
+	ID        int64  `json:"id"`
+	IP        string `json:"ip"`
+	Blocked   bool   `json:"blocked"`
+	Timestamp int64  `json:"timestamp"`
+	Reason    string `json:"reason"`
+}
+
+type BuildInfo struct {
+	Qt         string `json:"qt"`         // QT version
+	Libtorrent string `json:"libtorrent"` // libtorrent version
+	Boost      string `json:"boost"`      // Boost version
+	Openssl    string `json:"openssl"`    // OpenSSL version
+	Bitness    int    `json:"bitness"`    // Application bitness (e.g.64-bit)
+}
+
+type Cookie struct {
+	Name           string `json:"name"`           // Cookie name
+	Domain         string `json:"domain"`         // Cookie domain
+	Path           string `json:"path"`           // Cookie path
+	Value          string `json:"value"`          // Cookie value
+	ExpirationDate int64  `json:"expirationDate"` // Seconds since epoch
+}
+
+// PieceState represents download state of torrent pieces.
+type PieceState int
+
+const (
+	PieceStateNotDownloadYet    = 0
+	PieceStateNowDownloading    = 1
+	PieceStateAlreadyDownloaded = 2
+)
+
+// silence unused variable warnings
+var _ = PieceStateNotDownloadYet
+var _ = PieceStateNowDownloading
+var _ = PieceStateAlreadyDownloaded
+
+type WebSeed struct {
+	URL string `json:"url"`
+}
